🔖 [Table of Contents](README.md)

# FAQ

## How to spell Zrb?

You can spell Zrb as `Zaruba`.

## Why Python?

Python is a multipurpose language. It gives you a lot of flexibility to define your taska without being too verbose.


🔖 [Table of Contents](README.md)